==> huaweicloudsdkcc-3.1.126-py2.py3-none-any.whl: huaweicloudsdkcc/v3/model/disassociate_global_connection_bandwidth_instance_request_body.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class DisassociateGlobalConnectionBandwidthInstanceRequestBody:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'gcbandwidths': 'list[DisassociateGlobalConnectionBandwidthInstanceRequestInfo]'
    }

    attribute_map = {
        'gcbandwidths': 'gcbandwidths'
    }

    def __init__(self, gcbandwidths=None):
        """DisassociateGlobalConnectionBandwidthInstanceRequestBody

        The model defined in huaweicloud sdk

        :param gcbandwidths: 全域互联带宽解绑实例详细信息。
        :type gcbandwidths: list[:class:`huaweicloudsdkcc.v3.DisassociateGlobalConnectionBandwidthInstanceRequestInfo`]
        """
        
        

        self._gcbandwidths = None
        self.discriminator = None

        self.gcbandwidths = gcbandwidths

    @property
    def gcbandwidths(self):
        """Gets the gcbandwidths of this DisassociateGlobalConnectionBandwidthInstanceRequestBody.

        全域互联带宽解绑实例详细信息。

        :return: The gcbandwidths of this DisassociateGlobalConnectionBandwidthInstanceRequestBody.
        :rtype: list[:class:`huaweicloudsdkcc.v3.DisassociateGlobalConnectionBandwidthInstanceRequestInfo`]
        """
        return self._gcbandwidths

    @gcbandwidths.setter
    def gcbandwidths(self, gcbandwidths):
        """Sets the gcbandwidths of this DisassociateGlobalConnectionBandwidthInstanceRequestBody.

        全域互联带宽解绑实例详细信息。

        :param gcbandwidths: The gcbandwidths of this DisassociateGlobalConnectionBandwidthInstanceRequestBody.
        :type gcbandwidths: list[:class:`huaweicloudsdkcc.v3.DisassociateGlobalConnectionBandwidthInstanceRequestInfo`]
        """
        self._gcbandwidths = gcbandwidths

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DisassociateGlobalConnectionBandwidthInstanceRequestBody):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkcc-3.1.153-py2.py3-none-any.whl: huaweicloudsdkcc/v3/model/disassociate_global_connection_bandwidth_instance_request_body.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class DisassociateGlobalConnectionBandwidthInstanceRequestBody:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'gcbandwidths': 'list[DisassociateGlobalConnectionBandwidthInstanceRequestInfo]'
    }

    attribute_map = {
        'gcbandwidths': 'gcbandwidths'
    }

    def __init__(self, gcbandwidths=None):
        r"""DisassociateGlobalConnectionBandwidthInstanceRequestBody

        The model defined in huaweicloud sdk

        :param gcbandwidths: 全域互联带宽解绑实例详细信息。
        :type gcbandwidths: list[:class:`huaweicloudsdkcc.v3.DisassociateGlobalConnectionBandwidthInstanceRequestInfo`]
        """
        
        

        self._gcbandwidths = None
        self.discriminator = None

        self.gcbandwidths = gcbandwidths

    @property
    def gcbandwidths(self):
        r"""Gets the gcbandwidths of this DisassociateGlobalConnectionBandwidthInstanceRequestBody.

        全域互联带宽解绑实例详细信息。

        :return: The gcbandwidths of this DisassociateGlobalConnectionBandwidthInstanceRequestBody.
        :rtype: list[:class:`huaweicloudsdkcc.v3.DisassociateGlobalConnectionBandwidthInstanceRequestInfo`]
        """
        return self._gcbandwidths

    @gcbandwidths.setter
    def gcbandwidths(self, gcbandwidths):
        r"""Sets the gcbandwidths of this DisassociateGlobalConnectionBandwidthInstanceRequestBody.

        全域互联带宽解绑实例详细信息。

        :param gcbandwidths: The gcbandwidths of this DisassociateGlobalConnectionBandwidthInstanceRequestBody.
        :type gcbandwidths: list[:class:`huaweicloudsdkcc.v3.DisassociateGlobalConnectionBandwidthInstanceRequestInfo`]
        """
        self._gcbandwidths = gcbandwidths

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DisassociateGlobalConnectionBandwidthInstanceRequestBody):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
